@@ -15,11 +15,11 @@
 #    under the License.
 
 from django import template
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import ugettext_lazy as _  # noqa
 
-from horizon.tables import DataTable
+from horizon.browsers.breadcrumb import Breadcrumb  # noqa
+from horizon.tables import DataTable  # noqa
 from horizon.utils import html
-from .breadcrumb import Breadcrumb
 
 
 class ResourceBrowser(html.HTMLElement):
