@@ -30,7 +30,7 @@ horizon.modals.initModal = function (modal) {
 /* Creates a modal dialog from the client-side template. */
 horizon.modals.create = function (title, body, confirm, cancel) {
   if (!cancel) {
-    cancel = "Cancel";
+    cancel = gettext("Cancel");
   }
   var template = horizon.templates.compiled_templates["#modal_template"],
     params = {title: title, body: body, confirm: confirm, cancel: cancel},
@@ -95,7 +95,7 @@ horizon.addInitFunction(function() {
       data: $form.serialize(),
       beforeSend: function () {
         $("#modal_wrapper .modal").last().modal("hide");
-        horizon.modals.modal_spinner("Working");
+        horizon.modals.modal_spinner(gettext("Working"));
       },
       complete: function () {
         horizon.modals.spinner.modal('hide');
@@ -121,8 +121,12 @@ horizon.addInitFunction(function() {
         }
       },
       error: function (jqXHR, status, errorThrown) {
-        $form.closest(".modal").modal("hide");
-        horizon.alert("error", gettext("There was an error submitting the form. Please try again."));
+        if (jqXHR.getResponseHeader('logout')) {
+          location.href = jqXHR.getResponseHeader("X-Horizon-Location");
+        } else {
+          $form.closest(".modal").modal("hide");
+          horizon.alert("error", gettext("There was an error submitting the form. Please try again."));
+        }
       }
     });
   });
@@ -175,7 +179,7 @@ horizon.addInitFunction(function() {
         else {
           if (!horizon.ajax.get_messages(jqXHR)) {
             // Generic error handler. Really generic.
-            horizon.alert("error", gettext("An error occurred. Please try again."));
+            horizon.alert("error", gettext("An error occurred. Please try again later."));
           }
         }
       },
