@@ -3,7 +3,7 @@
 import os
 import sys
 
-from django.core.management import execute_from_command_line
+from django.core.management import execute_from_command_line  # noqa
 
 if __name__ == "__main__":
     os.environ.setdefault("DJANGO_SETTINGS_MODULE",
