@@ -14,19 +14,14 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import logging
-
-from django.core.urlresolvers import reverse
-from django.utils.translation import ugettext_lazy as _
+from django.core.urlresolvers import reverse  # noqa
+from django.utils.translation import ugettext_lazy as _  # noqa
 
 from horizon import tables
 
 from openstack_dashboard import api
 
 
-LOG = logging.getLogger(__name__)
-
-
 class ExtraSpecDelete(tables.DeleteAction):
     data_type_singular = _("ExtraSpec")
     data_type_plural = _("ExtraSpecs")
