@@ -14,20 +14,19 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import logging
-import re
-
-from django.utils.translation import ugettext as _
+from django.utils.translation import ugettext_lazy as _  # noqa
 
 from horizon import exceptions
 from horizon import forms
 from horizon.utils import fields
+from horizon.utils import validators
 from horizon import workflows
 
 from openstack_dashboard import api
 
 
-LOG = logging.getLogger(__name__)
+AVAILABLE_PROTOCOLS = ('HTTP', 'HTTPS', 'TCP')
+AVAILABLE_METHODS = ('ROUND_ROBIN', 'LEAST_CONNECTIONS', 'SOURCE_IP')
 
 
 class AddPoolAction(workflows.Action):
@@ -35,6 +34,9 @@ class AddPoolAction(workflows.Action):
     description = forms.CharField(
         initial="", required=False,
         max_length=80, label=_("Description"))
+    # provider is optional because some LBaaS implemetation does
+    # not support service-type extension.
+    provider = forms.ChoiceField(label=_("Provider"), required=False)
     subnet_id = forms.ChoiceField(label=_("Subnet"))
     protocol = forms.ChoiceField(label=_("Protocol"))
     lb_method = forms.ChoiceField(label=_("Load Balancing Method"))
@@ -48,8 +50,8 @@ class AddPoolAction(workflows.Action):
 
         subnet_id_choices = [('', _("Select a Subnet"))]
         try:
-            networks = api.quantum.network_list_for_tenant(request, tenant_id)
-        except:
+            networks = api.neutron.network_list_for_tenant(request, tenant_id)
+        except Exception:
             exceptions.handle(request,
                               _('Unable to retrieve networks list.'))
             networks = []
@@ -59,31 +61,62 @@ class AddPoolAction(workflows.Action):
         self.fields['subnet_id'].choices = subnet_id_choices
 
         protocol_choices = [('', _("Select a Protocol"))]
-        protocol_choices.append(('HTTP', 'HTTP'))
-        protocol_choices.append(('HTTPS', 'HTTPS'))
+        [protocol_choices.append((p, p)) for p in AVAILABLE_PROTOCOLS]
         self.fields['protocol'].choices = protocol_choices
 
-        lb_method_choices = [('', _("Select a Protocol"))]
-        lb_method_choices.append(('ROUND_ROBIN', 'ROUND_ROBIN'))
-        lb_method_choices.append(('LEAST_CONNECTIONS', 'LEAST_CONNECTIONS'))
-        lb_method_choices.append(('SOURCE_IP', 'SOURCE_IP'))
+        lb_method_choices = [('', _("Select a Method"))]
+        [lb_method_choices.append((m, m)) for m in AVAILABLE_METHODS]
         self.fields['lb_method'].choices = lb_method_choices
 
+        # provider choice
+        try:
+            if api.neutron.is_extension_supported(request, 'service-type'):
+                provider_list = api.neutron.provider_list(request)
+                providers = [p for p in provider_list
+                             if p['service_type'] == 'LOADBALANCER']
+            else:
+                providers = None
+        except Exception:
+            exceptions.handle(request,
+                              _('Unable to retrieve providers list.'))
+            providers = []
+
+        if providers:
+            default_providers = [p for p in providers if p.get('default')]
+            if default_providers:
+                default_provider = default_providers[0]['name']
+            else:
+                default_provider = None
+            provider_choices = [(p['name'], p['name']) for p in providers
+                                if p['name'] != default_provider]
+            if default_provider:
+                provider_choices.insert(
+                    0, (default_provider,
+                        _("%s (default)") % default_provider))
+        else:
+            if providers is None:
+                msg = _("Provider for Load Balancer is not supported.")
+            else:
+                msg = _("No provider is available.")
+            provider_choices = [('', msg)]
+            self.fields['provider'].widget.attrs['readonly'] = True
+        self.fields['provider'].choices = provider_choices
+
     class Meta:
-        name = _("PoolDetails")
+        name = _("Add New Pool")
         permissions = ('openstack.services.network',)
-        help_text = _("Create Pool for current tenant.\n\n"
+        help_text = _("Create Pool for current project.\n\n"
                       "Assign a name and description for the pool. "
                       "Choose one subnet where all members of this "
                       "pool must be on. "
                       "Select the protocol and load balancing method "
                       "for this pool. "
-                      "Admin State is UP (checked) by defaul.t")
+                      "Admin State is UP (checked) by default.")
 
 
 class AddPoolStep(workflows.Step):
     action_class = AddPoolAction
-    contributes = ("name", "description", "subnet_id",
+    contributes = ("name", "description", "subnet_id", "provider",
                    "protocol", "lb_method", "admin_state_up")
 
     def contribute(self, data, context):
@@ -96,8 +129,8 @@ class AddPool(workflows.Workflow):
     slug = "addpool"
     name = _("Add Pool")
     finalize_button_name = _("Add")
-    success_message = _('Added Pool "%s".')
-    failure_message = _('Unable to add Pool "%s".')
+    success_message = _('Added pool "%s".')
+    failure_message = _('Unable to add pool "%s".')
     success_url = "horizon:project:loadbalancers:index"
     default_steps = (AddPoolStep,)
 
@@ -107,11 +140,9 @@ class AddPool(workflows.Workflow):
 
     def handle(self, request, context):
         try:
-            pool = api.lbaas.pool_create(request, **context)
+            api.lbaas.pool_create(request, **context)
             return True
-        except:
-            msg = self.format_status_message(self.failure_message)
-            exceptions.handle(request, msg)
+        except Exception:
             return False
 
 
@@ -121,14 +152,17 @@ class AddVipAction(workflows.Action):
         initial="", required=False,
         max_length=80, label=_("Description"))
     floatip_address = forms.ChoiceField(
-        label=_("Vip Address from Floating IPs"),
+        label=_("VIP Address from Floating IPs"),
         widget=forms.Select(attrs={'disabled': 'disabled'}),
         required=False)
     other_address = fields.IPField(required=False,
                                    initial="",
                                    version=fields.IPv4,
                                    mask=False)
-    protocol_port = forms.CharField(max_length=80, label=_("Protocol Port"))
+    protocol_port = forms.IntegerField(label=_("Protocol Port"), min_value=1,
+                              help_text=_("Enter an integer value "
+                                          "between 1 and 65535."),
+                              validators=[validators.validate_port_range])
     protocol = forms.ChoiceField(label=_("Protocol"))
     session_persistence = forms.ChoiceField(
         required=False, initial={}, label=_("Session Persistence"))
@@ -137,8 +171,10 @@ class AddVipAction(workflows.Action):
         max_length=80, label=_("Cookie Name"),
         help_text=_("Required for APP_COOKIE persistence;"
                     " Ignored otherwise."))
-    connection_limit = forms.CharField(
-        max_length=80, label=_("Connection Limit"))
+    connection_limit = forms.IntegerField(
+        required=False, min_value=-1, label=_("Connection Limit"),
+        help_text=_("Maximum number of connections allowed "
+                    "for the VIP or '-1' if the limit is not set"))
     admin_state_up = forms.BooleanField(
         label=_("Admin State"), initial=True, required=False)
 
@@ -150,11 +186,10 @@ class AddVipAction(workflows.Action):
                                                args[0]['subnet'])
 
         protocol_choices = [('', _("Select a Protocol"))]
-        protocol_choices.append(('HTTP', 'HTTP'))
-        protocol_choices.append(('HTTPS', 'HTTPS'))
+        [protocol_choices.append((p, p)) for p in AVAILABLE_PROTOCOLS]
         self.fields['protocol'].choices = protocol_choices
 
-        session_persistence_choices = [('', _("Set Session Persistence"))]
+        session_persistence_choices = [('', _("No Session Persistence"))]
         for mode in ('SOURCE_IP', 'HTTP_COOKIE', 'APP_COOKIE'):
             session_persistence_choices.append((mode, mode))
         self.fields[
@@ -163,14 +198,22 @@ class AddVipAction(workflows.Action):
         floatip_address_choices = [('', _("Currently Not Supported"))]
         self.fields['floatip_address'].choices = floatip_address_choices
 
+    def clean(self):
+        cleaned_data = super(AddVipAction, self).clean()
+        if (cleaned_data.get('session_persistence') == 'APP_COOKIE' and
+                not cleaned_data.get('cookie_name')):
+            msg = _('Cookie name is required for APP_COOKIE persistence.')
+            self._errors['cookie_name'] = self.error_class([msg])
+        return cleaned_data
+
     class Meta:
-        name = _("AddVip")
+        name = _("Specify VIP")
         permissions = ('openstack.services.network',)
-        help_text = _("Create a vip (virtual IP) for this pool. "
-                      "Assign a name and description for the vip. "
-                      "Specify an IP address and port for the vip. "
+        help_text = _("Create a VIP for this pool. "
+                      "Assign a name and description for the VIP. "
+                      "Specify an IP address and port for the VIP. "
                       "Choose the protocol and session persistence "
-                      "method for the vip."
+                      "method for the VIP."
                       "Specify the max connections allowed. "
                       "Admin State is UP (checked) by default.")
 
@@ -190,10 +233,10 @@ class AddVipStep(workflows.Step):
 
 class AddVip(workflows.Workflow):
     slug = "addvip"
-    name = _("Add Vip")
+    name = _("Add VIP")
     finalize_button_name = _("Add")
-    success_message = _('Added Vip "%s".')
-    failure_message = _('Unable to add Vip "%s".')
+    success_message = _('Added VIP "%s".')
+    failure_message = _('Unable to add VIP "%s".')
     success_url = "horizon:project:loadbalancers:index"
     default_steps = (AddVipStep,)
 
@@ -206,31 +249,26 @@ class AddVip(workflows.Workflow):
             context['address'] = context['floatip_address']
         else:
             if not context['floatip_address'] == '':
-                self.failure_message = _('Only one address can be specified.'
-                                         'Unable to add Vip %s.')
+                self.failure_message = _('Only one address can be specified. '
+                                         'Unable to add VIP "%s".')
                 return False
             else:
                 context['address'] = context['other_address']
         try:
             pool = api.lbaas.pool_get(request, context['pool_id'])
             context['subnet_id'] = pool['subnet_id']
-        except:
+        except Exception:
             context['subnet_id'] = None
-            exceptions.handle(request,
-                              _('Unable to retrieve pool.'))
+            self.failure_message = _('Unable to retrieve the specified pool. '
+                                     'Unable to add VIP "%s".')
             return False
 
         if context['session_persistence']:
             stype = context['session_persistence']
             if stype == 'APP_COOKIE':
-                if context['cookie_name'] == "":
-                    self.failure_message = _('Cookie name must be specified '
-                                             'with APP_COOKIE persistence.')
-                    return False
-                else:
-                    cookie = context['cookie_name']
-                    context['session_persistence'] = {'type': stype,
-                                                      'cookie_name': cookie}
+                cookie = context['cookie_name']
+                context['session_persistence'] = {'type': stype,
+                                                  'cookie_name': cookie}
             else:
                 context['session_persistence'] = {'type': stype}
         else:
@@ -239,9 +277,7 @@ class AddVip(workflows.Workflow):
         try:
             api.lbaas.vip_create(request, **context)
             return True
-        except:
-            msg = self.format_status_message(self.failure_message)
-            exceptions.handle(request, msg)
+        except Exception:
             return False
 
 
@@ -252,9 +288,17 @@ class AddMemberAction(workflows.Action):
         required=True,
         initial=["default"],
         widget=forms.CheckboxSelectMultiple(),
+        error_messages={'required':
+                            _('At least one member must be specified')},
         help_text=_("Select members for this pool "))
-    weight = forms.CharField(max_length=80, label=_("Weight"))
-    protocol_port = forms.CharField(max_length=80, label=_("Protocol Port"))
+    weight = forms.IntegerField(max_value=256, min_value=0, label=_("Weight"),
+                                required=False,
+                                help_text=_("Relative part of requests this "
+                                "pool member serves compared to others"))
+    protocol_port = forms.IntegerField(label=_("Protocol Port"), min_value=1,
+                              help_text=_("Enter an integer value "
+                                          "between 1 and 65535."),
+                              validators=[validators.validate_port_range])
     admin_state_up = forms.BooleanField(label=_("Admin State"),
                                         initial=True, required=False)
 
@@ -264,7 +308,7 @@ class AddMemberAction(workflows.Action):
         pool_id_choices = [('', _("Select a Pool"))]
         try:
             pools = api.lbaas.pools_get(request)
-        except:
+        except Exception:
             pools = []
             exceptions.handle(request,
                               _('Unable to retrieve pools list.'))
@@ -276,8 +320,8 @@ class AddMemberAction(workflows.Action):
 
         members_choices = []
         try:
-            servers = api.nova.server_list(request)
-        except:
+            servers, has_more = api.nova.server_list(request)
+        except Exception:
             servers = []
             exceptions.handle(request,
                               _('Unable to retrieve instances list.'))
@@ -289,7 +333,6 @@ class AddMemberAction(workflows.Action):
             self.fields['members'].help_text = _("Select members "
                                                  "for this pool ")
             self.fields['pool_id'].required = False
-            self.fields['weight'].required = False
             self.fields['protocol_port'].required = False
             return
 
@@ -300,7 +343,7 @@ class AddMemberAction(workflows.Action):
             key=lambda member: member[1])
 
     class Meta:
-        name = _("MemberDetails")
+        name = _("Add New Member")
         permissions = ('openstack.services.network',)
         help_text = _("Add member to selected pool.\n\n"
                       "Choose one or more listed instances to be "
@@ -324,83 +367,125 @@ class AddMember(workflows.Workflow):
     slug = "addmember"
     name = _("Add Member")
     finalize_button_name = _("Add")
-    success_message = _('Added Member "%s".')
-    failure_message = _('Unable to add Member %s.')
+    success_message = _('Added member(s).')
+    failure_message = _('Unable to add member(s).')
     success_url = "horizon:project:loadbalancers:index"
     default_steps = (AddMemberStep,)
 
     def handle(self, request, context):
-        if context['members'] == []:
-            self.failure_message = _('No instances available.%s')
-            context['member_id'] = ''
-            return False
-
         for m in context['members']:
             params = {'device_id': m}
             try:
-                plist = api.quantum.port_list(request, **params)
-            except:
-                plist = []
-                exceptions.handle(request,
-                                  _('Unable to retrieve ports list.'))
+                plist = api.neutron.port_list(request, **params)
+            except Exception:
                 return False
             if plist:
                 context['address'] = plist[0].fixed_ips[0]['ip_address']
             try:
                 context['member_id'] = api.lbaas.member_create(
                     request, **context).id
-            except:
-                exceptions.handle(request, _("Unable to add member."))
+            except Exception:
                 return False
         return True
 
 
 class AddMonitorAction(workflows.Action):
-    pool_id = forms.ChoiceField(label=_("Pool"))
-    type = forms.ChoiceField(label=_("Type"))
-    delay = forms.CharField(max_length=80, label=_("Delay"))
-    timeout = forms.CharField(max_length=80, label=_("Timeout"))
-    max_retries = forms.CharField(max_length=80,
-                                  label=_("Max Retries (1~10)"))
+    type = forms.ChoiceField(
+        label=_("Type"),
+        choices=[('ping', _('PING')),
+                 ('tcp', _('TCP')),
+                 ('http', _('HTTP')),
+                 ('https', _('HTTPS'))],
+        widget=forms.Select(attrs={
+            'class': 'switchable',
+            'data-slug': 'type'
+        }))
+    delay = forms.IntegerField(
+        min_value=1,
+        label=_("Delay"),
+        help_text=_("The minimum time in seconds between regular checks "
+                    "of a member"))
+    timeout = forms.IntegerField(
+        min_value=1,
+        label=_("Timeout"),
+        help_text=_("The maximum time in seconds for a monitor to wait "
+                    "for a reply"))
+    max_retries = forms.IntegerField(
+        max_value=10, min_value=1,
+        label=_("Max Retries (1~10)"),
+        help_text=_("Number of permissible failures before changing "
+                    "the status of member to inactive"))
     http_method = forms.ChoiceField(
-        initial="GET", required=False, label=_("HTTP Method"))
+        initial="GET",
+        required=False,
+        choices=[('GET', _('GET'))],
+        label=_("HTTP Method"),
+        help_text=_("HTTP method used to check health status of a member"),
+        widget=forms.Select(attrs={
+            'class': 'switched',
+            'data-switch-on': 'type',
+            'data-type-http': _('HTTP Method'),
+            'data-type-https': _('HTTP Method')
+        }))
     url_path = forms.CharField(
-        initial="/", required=False, max_length=80, label=_("URL"))
-    expected_codes = forms.CharField(
-        initial="200", required=False, max_length=80,
-        label=_("Expected HTTP Status Codes"))
+        initial="/",
+        required=False,
+        max_length=80,
+        label=_("URL"),
+        widget=forms.TextInput(attrs={
+            'class': 'switched',
+            'data-switch-on': 'type',
+            'data-type-http': _('URL'),
+            'data-type-https': _('URL')
+        }))
+    expected_codes = forms.RegexField(
+        initial="200",
+        required=False,
+        max_length=80,
+        regex=r'^(\d{3}(\s*,\s*\d{3})*)$|^(\d{3}-\d{3})$',
+        label=_("Expected HTTP Status Codes"),
+        help_text=_("Expected code may be a single value (e.g. 200), "
+                    "a list of values (e.g. 200, 202), "
+                    "or range of values (e.g. 200-204)"),
+        widget=forms.TextInput(attrs={
+            'class': 'switched',
+            'data-switch-on': 'type',
+            'data-type-http': _('Expected HTTP Status Codes'),
+            'data-type-https': _('Expected HTTP Status Codes')
+        }))
     admin_state_up = forms.BooleanField(label=_("Admin State"),
                                         initial=True, required=False)
 
     def __init__(self, request, *args, **kwargs):
         super(AddMonitorAction, self).__init__(request, *args, **kwargs)
 
-        pool_id_choices = [('', _("Select a Pool"))]
-        try:
-            pools = api.lbaas.pools_get(request)
-            for p in pools:
-                pool_id_choices.append((p.id, p.name))
-        except:
-            exceptions.handle(request,
-                              _('Unable to retrieve pools list.'))
-        self.fields['pool_id'].choices = pool_id_choices
+    def clean(self):
+        cleaned_data = super(AddMonitorAction, self).clean()
+        type_opt = cleaned_data.get('type')
 
-        type_choices = [('', _("Select Type"))]
-        type_choices.append(('PING', 'PING'))
-        type_choices.append(('TCP', 'TCP'))
-        type_choices.append(('HTTP', 'HTTP'))
-        type_choices.append(('HTTPS', 'HTTPS'))
-        self.fields['type'].choices = type_choices
+        if type_opt in ['http', 'https']:
+            http_method_opt = cleaned_data.get('http_method')
+            url_path = cleaned_data.get('url_path')
+            expected_codes = cleaned_data.get('expected_codes')
 
-        http_method_choices = [('', _("Select HTTP Method"))]
-        http_method_choices.append(('GET', 'GET'))
-        self.fields['http_method'].choices = http_method_choices
+            if not http_method_opt:
+                msg = _('Please choose a HTTP method')
+                self._errors['http_method'] = self.error_class([msg])
+            if not url_path:
+                msg = _('Please specify an URL')
+                self._errors['url_path'] = self.error_class([msg])
+            if not expected_codes:
+                msg = _('Please enter a single value (e.g. 200), '
+                        'a list of values (e.g. 200, 202), '
+                        'or range of values (e.g. 200-204)')
+                self._errors['expected_codes'] = self.error_class([msg])
+        return cleaned_data
 
     class Meta:
-        name = _("MonitorDetails")
+        name = _("Add New Monitor")
         permissions = ('openstack.services.network',)
-        help_text = _("Create a monitor for a pool.\n\n"
-                      "Select target pool and type of monitoring. "
+        help_text = _("Create a monitor template.\n\n"
+                      "Select type of monitoring. "
                       "Specify delay, timeout, and retry limits "
                       "required by the monitor. "
                       "Specify method, URL path, and expected "
@@ -409,7 +494,7 @@ class AddMonitorAction(workflows.Action):
 
 class AddMonitorStep(workflows.Step):
     action_class = AddMonitorAction
-    contributes = ("pool_id", "type", "delay", "timeout", "max_retries",
+    contributes = ("type", "delay", "timeout", "max_retries",
                    "http_method", "url_path", "expected_codes",
                    "admin_state_up")
 
@@ -423,8 +508,8 @@ class AddMonitor(workflows.Workflow):
     slug = "addmonitor"
     name = _("Add Monitor")
     finalize_button_name = _("Add")
-    success_message = _('Added Monitor "%s".')
-    failure_message = _('Unable to add Monitor "%s".')
+    success_message = _('Added monitor')
+    failure_message = _('Unable to add monitor')
     success_url = "horizon:project:loadbalancers:index"
     default_steps = (AddMonitorStep,)
 
@@ -433,6 +518,124 @@ class AddMonitor(workflows.Workflow):
             context['monitor_id'] = api.lbaas.pool_health_monitor_create(
                 request, **context).get('id')
             return True
-        except:
+        except Exception:
             exceptions.handle(request, _("Unable to add monitor."))
         return False
+
+
+class AddPMAssociationAction(workflows.Action):
+    monitor_id = forms.ChoiceField(label=_("Monitor"))
+
+    def __init__(self, request, *args, **kwargs):
+        super(AddPMAssociationAction, self).__init__(request, *args, **kwargs)
+
+    def populate_monitor_id_choices(self, request, context):
+        self.fields['monitor_id'].label = _("Select a monitor template "
+                                            "for %s" % context['pool_name'])
+
+        monitor_id_choices = [('', _("Select a Monitor"))]
+        try:
+            monitors = api.lbaas.pool_health_monitors_get(request)
+            for m in monitors:
+                if m.id not in context['pool_monitors']:
+                    monitor_id_choices.append((m.id, m.id))
+        except Exception:
+            exceptions.handle(request,
+                              _('Unable to retrieve monitors list.'))
+        self.fields['monitor_id'].choices = monitor_id_choices
+
+        return monitor_id_choices
+
+    class Meta:
+        name = _("Association Details")
+        permissions = ('openstack.services.network',)
+        help_text = _("Associate a health monitor with target pool.")
+
+
+class AddPMAssociationStep(workflows.Step):
+    action_class = AddPMAssociationAction
+    depends_on = ("pool_id", "pool_name", "pool_monitors")
+    contributes = ("monitor_id",)
+
+    def contribute(self, data, context):
+        context = super(AddPMAssociationStep, self).contribute(data, context)
+        if data:
+            return context
+
+
+class AddPMAssociation(workflows.Workflow):
+    slug = "addassociation"
+    name = _("Add Association")
+    finalize_button_name = _("Add")
+    success_message = _('Added association.')
+    failure_message = _('Unable to add association.')
+    success_url = "horizon:project:loadbalancers:index"
+    default_steps = (AddPMAssociationStep,)
+
+    def handle(self, request, context):
+        try:
+            context['monitor_id'] = api.lbaas.pool_monitor_association_create(
+                request, **context)
+            return True
+        except Exception:
+            exceptions.handle(request, _("Unable to add association."))
+        return False
+
+
+class DeletePMAssociationAction(workflows.Action):
+    monitor_id = forms.ChoiceField(label=_("Monitor"))
+
+    def __init__(self, request, *args, **kwargs):
+        super(DeletePMAssociationAction, self).__init__(
+            request, *args, **kwargs)
+
+    def populate_monitor_id_choices(self, request, context):
+        self.fields['monitor_id'].label = (_("Select a health monitor of %s") %
+                                           context['pool_name'])
+
+        monitor_id_choices = [('', _("Select a Monitor"))]
+        try:
+            for m_id in context['pool_monitors']:
+                monitor_id_choices.append((m_id, m_id))
+        except Exception:
+            exceptions.handle(request,
+                              _('Unable to retrieve monitors list.'))
+        self.fields['monitor_id'].choices = monitor_id_choices
+
+        return monitor_id_choices
+
+    class Meta:
+        name = _("Association Details")
+        permissions = ('openstack.services.network',)
+        help_text = _("Disassociate a health monitor from target pool. ")
+
+
+class DeletePMAssociationStep(workflows.Step):
+    action_class = DeletePMAssociationAction
+    depends_on = ("pool_id", "pool_name", "pool_monitors")
+    contributes = ("monitor_id",)
+
+    def contribute(self, data, context):
+        context = super(DeletePMAssociationStep, self).contribute(
+            data, context)
+        if data:
+            return context
+
+
+class DeletePMAssociation(workflows.Workflow):
+    slug = "deleteassociation"
+    name = _("Delete Association")
+    finalize_button_name = _("Delete")
+    success_message = _('Deleted association.')
+    failure_message = _('Unable to delete association.')
+    success_url = "horizon:project:loadbalancers:index"
+    default_steps = (DeletePMAssociationStep,)
+
+    def handle(self, request, context):
+        try:
+            context['monitor_id'] = api.lbaas.pool_monitor_association_delete(
+                request, **context)
+            return True
+        except Exception:
+            exceptions.handle(request, _("Unable to delete association."))
+        return False
