@@ -15,37 +15,34 @@
 #    under the License.
 
 """
-Views for managing Quantum Subnets.
+Views for managing Neutron Subnets.
 """
-import logging
-
-from django.core.urlresolvers import reverse_lazy, reverse
-from django.utils.translation import ugettext_lazy as _
+from django.core.urlresolvers import reverse  # noqa
+from django.utils.translation import ugettext_lazy as _  # noqa
 
 from horizon import exceptions
 from horizon import tabs
 from horizon import workflows
 
 from openstack_dashboard import api
-from .tabs import SubnetDetailTabs
-from .workflows import CreateSubnet, UpdateSubnet
 
-
-LOG = logging.getLogger(__name__)
+from openstack_dashboard.dashboards.project.networks.subnets \
+    import tabs as project_tabs
+from openstack_dashboard.dashboards.project.networks.subnets \
+    import workflows as project_workflows
 
 
 class CreateView(workflows.WorkflowView):
-    workflow_class = CreateSubnet
-    template_name = 'project/networks/subnets/create.html'
+    workflow_class = project_workflows.CreateSubnet
 
     def get_object(self):
         if not hasattr(self, "_object"):
             try:
                 network_id = self.kwargs["network_id"]
-                self._object = api.quantum.network_get(self.request,
+                self._object = api.neutron.network_get(self.request,
                                                        network_id)
                 self._object.set_id_as_name_if_empty()
-            except:
+            except Exception:
                 redirect = reverse('horizon:project:networks:index')
                 msg = _("Unable to retrieve network.")
                 exceptions.handle(self.request, msg, redirect=redirect)
@@ -58,15 +55,14 @@ class CreateView(workflows.WorkflowView):
 
 
 class UpdateView(workflows.WorkflowView):
-    workflow_class = UpdateSubnet
-    template_name = 'project/networks/subnets/update.html'
+    workflow_class = project_workflows.UpdateSubnet
 
     def _get_object(self, *args, **kwargs):
         if not hasattr(self, "_object"):
             subnet_id = self.kwargs['subnet_id']
             try:
-                self._object = api.quantum.subnet_get(self.request, subnet_id)
-            except:
+                self._object = api.neutron.subnet_get(self.request, subnet_id)
+            except Exception:
                 redirect = reverse("horizon:project:networks:index")
                 msg = _('Unable to retrieve subnet details')
                 exceptions.handle(self.request, msg, redirect=redirect)
@@ -99,5 +95,5 @@ class UpdateView(workflows.WorkflowView):
 
 
 class DetailView(tabs.TabView):
-    tab_group_class = SubnetDetailTabs
+    tab_group_class = project_tabs.SubnetDetailTabs
     template_name = 'project/networks/subnets/detail.html'
