@@ -16,14 +16,14 @@
 
 import logging
 
-from django.core.urlresolvers import reverse
-from django.utils.translation import ugettext_lazy as _
+from django.core.urlresolvers import reverse  # noqa
+from django.utils.translation import ugettext_lazy as _  # noqa
 
 from horizon import exceptions
 from horizon import tables
 from openstack_dashboard import api
-from openstack_dashboard.dashboards.project.networks.ports.tables import\
-        get_fixed_ips
+from openstack_dashboard.dashboards.project.networks.ports \
+    import tables as project_tables
 
 LOG = logging.getLogger(__name__)
 
@@ -56,14 +56,14 @@ class RemoveInterface(tables.DeleteAction):
     def delete(self, request, obj_id):
         try:
             router_id = self.table.kwargs['router_id']
-            port = api.quantum.port_get(request, obj_id)
+            port = api.neutron.port_get(request, obj_id)
             if port['device_owner'] == 'network:router_gateway':
-                api.quantum.router_remove_gateway(request, router_id)
+                api.neutron.router_remove_gateway(request, router_id)
             else:
-                api.quantum.router_remove_interface(request,
+                api.neutron.router_remove_interface(request,
                                                     router_id,
                                                     port_id=obj_id)
-        except:
+        except Exception:
             msg = _('Failed to delete interface %s') % obj_id
             LOG.info(msg)
             router_id = self.table.kwargs['router_id']
@@ -71,12 +71,18 @@ class RemoveInterface(tables.DeleteAction):
                                args=[router_id])
             exceptions.handle(request, msg, redirect=redirect)
 
+    def allowed(self, request, datum=None):
+        if datum and datum['device_owner'] == 'network:router_gateway':
+            return False
+        return True
+
 
 class PortsTable(tables.DataTable):
     name = tables.Column("name",
                          verbose_name=_("Name"),
                          link="horizon:project:networks:ports:detail")
-    fixed_ips = tables.Column(get_fixed_ips, verbose_name=_("Fixed IPs"))
+    fixed_ips = tables.Column(project_tables.get_fixed_ips,
+                              verbose_name=_("Fixed IPs"))
     status = tables.Column("status", verbose_name=_("Status"))
     device_owner = tables.Column(get_device_owner,
                                  verbose_name=_("Type"))
