@@ -18,35 +18,44 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from functools import wraps
+from functools import wraps  # noqa
 import os
 
-from django import http
-from django.conf import settings
-from django.contrib.messages.storage import default_storage
-from django.contrib.auth.middleware import AuthenticationMiddleware
+from django.conf import settings  # noqa
+from django.contrib.auth.middleware import AuthenticationMiddleware  # noqa
+from django.contrib.messages.storage import default_storage  # noqa
 from django.core.handlers import wsgi
-from django.test.client import RequestFactory
+from django import http
+from django.test.client import RequestFactory  # noqa
+from django.utils.importlib import import_module  # noqa
 from django.utils import unittest
 
-import glanceclient
-from keystoneclient.v2_0 import client as keystone_client
-from novaclient.v1_1 import client as nova_client
-from quantumclient.v2_0 import client as quantum_client
-from swiftclient import client as swift_client
+from ceilometerclient.v2 import client as ceilometer_client
 from cinderclient import client as cinder_client
+import glanceclient
+from heatclient import client as heat_client
+from keystoneclient.v2_0 import client as keystone_client
+from neutronclient.v2_0 import client as neutron_client
+from novaclient.v1_1 import client as nova_client
+from swiftclient import client as swift_client
+try:
+    from troveclient import client as trove_client
+    with_trove = True
+except ImportError:
+    with_trove = False
 
 import httplib2
 import mox
 
-from openstack_auth import utils, user
+from openstack_auth import user
+from openstack_auth import utils
 
-from horizon.test import helpers as horizon_helpers
 from horizon import middleware
+from horizon.test import helpers as horizon_helpers
 
 from openstack_dashboard import api
 from openstack_dashboard import context_processors
-from openstack_dashboard.test.test_data.utils import load_test_data
+from openstack_dashboard.test.test_data import utils as test_utils
 
 
 # Makes output of failing mox tests much easier to read.
@@ -60,7 +69,7 @@ def create_stubs(stubs_to_create={}):
 
     def inner_stub_out(fn):
         @wraps(fn)
-        def instance_stub_out(self):
+        def instance_stub_out(self, *args, **kwargs):
             for key in stubs_to_create:
                 if not (isinstance(stubs_to_create[key], tuple) or
                         isinstance(stubs_to_create[key], list)):
@@ -71,7 +80,7 @@ def create_stubs(stubs_to_create={}):
 
                 for value in stubs_to_create[key]:
                     self.mox.StubOutWithMock(key, value)
-            return fn(self)
+            return fn(self, *args, **kwargs)
         return instance_stub_out
     return inner_stub_out
 
@@ -112,7 +121,7 @@ class TestCase(horizon_helpers.TestCase):
       * Several handy additional assertion methods.
     """
     def setUp(self):
-        load_test_data(self)
+        test_utils.load_test_data(self)
         self.mox = mox.Mox()
         self.factory = RequestFactoryWithMessages()
         self.context = {'authorized_tenants': self.tenants.list()}
@@ -202,8 +211,8 @@ class TestCase(horizon_helpers.TestCase):
         errors = response.context[context_name]._errors
         if count:
             assert len(errors) == count, \
-               "%d errors were found on the form, %d expected" % \
-               (len(errors), count)
+                "%d errors were found on the form, %d expected" % \
+                (len(errors), count)
             if message and message not in unicode(errors):
                 self.fail("Expected message not found, instead found: %s"
                           % ["%s: %s" % (key, [e for e in field_errors]) for
@@ -222,6 +231,17 @@ class BaseAdminViewTests(TestCase):
             kwargs['roles'] = [self.roles.admin._info]
         super(BaseAdminViewTests, self).setActiveUser(*args, **kwargs)
 
+    def setSessionValues(self, **kwargs):
+        settings.SESSION_ENGINE = 'django.contrib.sessions.backends.file'
+        engine = import_module(settings.SESSION_ENGINE)
+        store = engine.SessionStore()
+        for key in kwargs:
+            store[key] = kwargs[key]
+            self.request.session[key] = kwargs[key]
+        store.save()
+        self.session = store
+        self.client.cookies[settings.SESSION_COOKIE_NAME] = store.session_key
+
 
 class APITestCase(TestCase):
     """
@@ -231,6 +251,7 @@ class APITestCase(TestCase):
     """
     def setUp(self):
         super(APITestCase, self).setUp()
+        utils.patch_middleware_get_user()
 
         def fake_keystoneclient(request, admin=False):
             """
@@ -244,23 +265,36 @@ class APITestCase(TestCase):
         self._original_glanceclient = api.glance.glanceclient
         self._original_keystoneclient = api.keystone.keystoneclient
         self._original_novaclient = api.nova.novaclient
-        self._original_quantumclient = api.quantum.quantumclient
+        self._original_neutronclient = api.neutron.neutronclient
         self._original_cinderclient = api.cinder.cinderclient
+        self._original_heatclient = api.heat.heatclient
+        self._original_ceilometerclient = api.ceilometer.ceilometerclient
+        if with_trove:
+            self._original_troveclient = api.trove.troveclient
 
         # Replace the clients with our stubs.
         api.glance.glanceclient = lambda request: self.stub_glanceclient()
         api.keystone.keystoneclient = fake_keystoneclient
         api.nova.novaclient = lambda request: self.stub_novaclient()
-        api.quantum.quantumclient = lambda request: self.stub_quantumclient()
+        api.neutron.neutronclient = lambda request: self.stub_neutronclient()
         api.cinder.cinderclient = lambda request: self.stub_cinderclient()
+        api.heat.heatclient = lambda request: self.stub_heatclient()
+        api.ceilometer.ceilometerclient = lambda request: \
+            self.stub_ceilometerclient()
+        if with_trove:
+            api.trove.troveclient = lambda request: self.stub_troveclient()
 
     def tearDown(self):
         super(APITestCase, self).tearDown()
         api.glance.glanceclient = self._original_glanceclient
         api.nova.novaclient = self._original_novaclient
         api.keystone.keystoneclient = self._original_keystoneclient
-        api.quantum.quantumclient = self._original_quantumclient
+        api.neutron.neutronclient = self._original_neutronclient
         api.cinder.cinderclient = self._original_cinderclient
+        api.heat.heatclient = self._original_heatclient
+        api.ceilometer.ceilometerclient = self._original_ceilometerclient
+        if with_trove:
+            api.trove.troveclient = self._original_troveclient
 
     def stub_novaclient(self):
         if not hasattr(self, "novaclient"):
@@ -291,11 +325,11 @@ class APITestCase(TestCase):
             self.glanceclient = self.mox.CreateMock(glanceclient.Client)
         return self.glanceclient
 
-    def stub_quantumclient(self):
-        if not hasattr(self, "quantumclient"):
-            self.mox.StubOutWithMock(quantum_client, 'Client')
-            self.quantumclient = self.mox.CreateMock(quantum_client.Client)
-        return self.quantumclient
+    def stub_neutronclient(self):
+        if not hasattr(self, "neutronclient"):
+            self.mox.StubOutWithMock(neutron_client, 'Client')
+            self.neutronclient = self.mox.CreateMock(neutron_client.Client)
+        return self.neutronclient
 
     def stub_swiftclient(self, expected_calls=1):
         if not hasattr(self, "swiftclient"):
@@ -307,11 +341,32 @@ class APITestCase(TestCase):
                                         None,
                                         preauthtoken=mox.IgnoreArg(),
                                         preauthurl=mox.IgnoreArg(),
+                                        cacert=None,
                                         auth_version="2.0") \
                             .AndReturn(self.swiftclient)
                 expected_calls -= 1
         return self.swiftclient
 
+    def stub_heatclient(self):
+        if not hasattr(self, "heatclient"):
+            self.mox.StubOutWithMock(heat_client, 'Client')
+            self.heatclient = self.mox.CreateMock(heat_client.Client)
+        return self.heatclient
+
+    def stub_ceilometerclient(self):
+        if not hasattr(self, "ceilometerclient"):
+            self.mox.StubOutWithMock(ceilometer_client, 'Client')
+            self.ceilometerclient = self.mox.\
+                CreateMock(ceilometer_client.Client)
+        return self.ceilometerclient
+
+    if with_trove:
+        def stub_troveclient(self):
+            if not hasattr(self, "troveclient"):
+                self.mox.StubOutWithMock(trove_client, 'Client')
+                self.troveclient = self.mox.CreateMock(trove_client.Client)
+            return self.troveclient
+
 
 @unittest.skipUnless(os.environ.get('WITH_SELENIUM', False),
                      "The WITH_SELENIUM env variable is not set.")
@@ -320,7 +375,7 @@ class SeleniumTestCase(horizon_helpers.SeleniumTestCase):
     def setUp(self):
         super(SeleniumTestCase, self).setUp()
 
-        load_test_data(self)
+        test_utils.load_test_data(self)
         self.mox = mox.Mox()
 
         self._real_get_user = utils.get_user
